var dir_b1e887c6bbcb717920d3f5d3630c5c1a =
[
    [ "widgets", "dir_fd9376342f695ab12a458ba6b6e55017.html", "dir_fd9376342f695ab12a458ba6b6e55017" ],
    [ "ColorPlugin.cc", "ColorPlugin_8cc_source.html", null ],
    [ "ColorPlugin.hh", "ColorPlugin_8hh_source.html", null ]
];